@@ -1046,7 +1046,7 @@ class DynamoCrudRepository(CrudRepository):
                     for entity in entity_list:
                         batch.delete_item(
                             Key=self._id2key_pair(
-                                str(getattr(entity, entity.dynamo_id()))
+                                getattr(entity, entity.dynamo_id())
                             )
                         )
         except Exception as ex:
@@ -1424,11 +1424,13 @@ class MultiTableDynamoCrudRepository(DynamoCrudRepository):
                         )
         except Exception as ex:
             try:
-                for entity in entity_list:
-                    keys= self._id2key_pair(getattr(entity, entity.dynamo_id()))
-                    batch.delete_item(
-                        Key=keys
-                    )
+                with self.table.batch_writer() as batch:
+                    for entity in entity_list:
+                        keys= self._id2key_pair(getattr(entity, entity.dynamo_id()))
+
+                        batch.delete_item(
+                            Key=keys
+                        )
             except Exception as ex:
                 print(ex)
                 warnings.warn(
